make_random_voronoi: Make a voronoi plot of random points

Description Usage Arguments Details Value

View source: R/make_random_voronoi.R

Description

Make a voronoi plot of random points

Usage

1
2
3
4
make_random_voronoi(shapes = sample(c(10, 100, 1000), 1),
  n_colors = round(shapes/2), gradient = TRUE, color_palette = NULL,
  palette_colors = get_palette_colors(color_palette, n_colors),
  fill_color = NULL, line_color = NULL, line_size = NULL)

Arguments

shapes

num number of shapes to make

n_colors

num number of colors to use in plot

gradient

logical should color gradient be used

color_palette

chr name of color palette to use

palette_colors

chr list of colors, usually generated from 'get_palette_colors()'

fill_color

chr name of color to be used for fill

line_color

chr name of color to be used for line

line_size

num size of line width

Details

Creates a data.frame of points length, with column 'x' drawn from random normal distribution, column 'y' from random uniform distribution, and column 'z' from random normal distribution.

Value

'ggplot' object


jimtheflash/arrrt documentation built on April 5, 2020, 11:49 a.m.